pocketpose.apis - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.apis`

## Module Contents

### Functions

`list_models`() | List all available models.
`create_model`(model_name, *args, **kwargs) | Create a model from its name.

pocketpose.apis.list_models()

  List all available models.

pocketpose.apis.create_model(model_name, *args, **kwargs)

  Create a model from its name.